	PROGRAM DKPLOT
c  Purpose:  The program provides screen/hardcopy plots of field
c            variation and regular daily variation curves.  A file
c            is output (*.DIF) that contains tabular differences
c            of digital K minus hand scaled K.  This information
c            may be used for evaluating the performance of the k0
c            program.
c  Author:  L. R. Wilson 11/5/92
c  Input:
c         -Binary file *.*, contains coded 1-minute values of H, D,
c          Z, and F.
c         -Binary file *.CRV, cubic spline coefficients for SR curve
c         -ASCII File *.DIG, contains statistics generated in
c          program K0.  These statistics are output on eac graph.
c         -ASCII file XX8586.KAY, contains handscaled K indices
c          for the IAGA WG-5 observatories for years 1985 and 1986
c          The "XX" represents the two character observatory
c          identification code.
c         -ASCII file *.DKA, is a table of digital K values that
c          was output by program K0.
c         -ASCII file OBSY.DAT is a database of observatory
C          parameters.
c         -ASCII file *.lst, is an optional file of selected days
c          that are to be graphed.  The day identification used is
c          the year minus 1970 concatinated with the day of the year.
c  Output:
c         -ASCII file *.DIF, table of digital K minus handscaled K
c          values.
c         -An optional file *.PLT may be generated on request for
c          plotting graphs using GRAFPRINT software.
c  Subroutines:
c         CHEAD1, CURVK, RDKA, RHDS, CTR3, KBG01, PSPLIN, RKV
C  Libraries:
C      D:\GENERAL\EXNAM, RND, OINFO
C      C:\F77L\F77L, C:\F77L\GRAPH, C:\F77L\VAXIBM
c

	CHARACTER IANS,IPRN,TIMEST*8,DATEST*9,IDATE*9
	CHARACTER ID3*3,STDATE*14
	CHARACTER*12 NAM1,NAM2,NAM3,NAM4
C      CHARACTER*24 ISTAT
	CHARACTER*31 NAM
	INTEGER*2 GETMO,GETDAY,INK,IER,IYJ,IZ,IZD,IB,IE,IDK,W,
     *INDX,GYJD,E,IERR
	REAL*4 B
	DIMENSION IZ(1986),IZD(1986),W(1440,2),INDX(9),PYAM(4),
     *NUM(10,8,7),ANUM(4)
c
	INTEGER*2 IX
	REAL*4 C,BOXH,BOXW,EO,XI,YI
	COMMON/ABLE/IX(5762),C,XI,YI,BOXH,BOXW,EO
C
	CHARACTER*2 ID
	INTEGER*2 MHI,MLO,RNG,MENDS,IDUM1
	COMMON/FOX/MHI(2),MLO(2),ID,XD,SV(2),SND(2,2),RNG(2),
     *MENDS(2),IDUM1(1963)
C
	INTEGER*2 NYJ,TEM1,NR,TEM2,I3R
	REAL*4 SESRC
	COMMON/GOLF/NYJ,TEM1(8),SESRC(31,8),NR(31,8),TEM2(8),I3R(31,8)
C
	INTEGER*2 IW,NS
	REAL*4 XX,B1,DEL
	COMMON/INDIA/IW(496),XX(124,2),B1(124,2),DEL(124,2),NS(2)
C
	INTEGER*2 NK
	REAL*4 DK
	COMMON/KVAL/DK(31,8),NK(31,8)
C
	CHARACTER*26 APARM
	INTEGER*2 IPARM(4),NPARM
	REAL*4 FPARM(4)
	COMMON/OBSYDAT/FPARM,IPARM,APARM,NPARM
      EQUIVALENCE(W(1,1),IX(1))
      EQUIVALENCE(IZ(1),MHI(1)),(IZD(1),IW(1))
C      DATA INDX/25,50,100,200,350,600,1000,1650,2500/
C
	C=1.0/2.54              !Graphs in cm converted to inches
	XI=3.5*C                !Initial coordinates of BOX
	YI=10.16*C
	BOXH=7.0                !in cm
	ANUM(1)=BOXH*20.        !2 nT/mm
	ANUM(2)=BOXH*50.        !5 nT/mm
	ANUM(3)=BOXH*100.       !10 nT/mm
	ANUM(4)=BOXH*250.       !25 nT/mm
	BOXH=BOXH*C             !BOX height
	BOXW=20.4*C             !BOX width
	EO=8.0*C                !Offset between boxes
	HSC=0.35*C              !Height of characters used to list
					! statistics on dK
	CALL DATE(DATEST)
	CALL TIME(TIMEST)
	WRITE(*,1000)                   !Get input filename
	READ (*,1006) NAM
	CALL UPPER(NAM,31)
	CALL GETFLN(NAM,NAM1,31)
	CALL OINFO(1,NAM1(1:2),'PYAM:')
C      ISTAT(1:24)=APARM(1:24)
	DO I=1,4
	  PYAM(I)=FPARM(I)
	ENDDO
	CALL OINFO(1,NAM1(1:2),'IDS:')
	ID3(1:3)=APARM(1:3)
	CALL OINFO(1,NAM1(1:2),'EAMP:')
	FMIN9=FPARM(1)
	CALL CURVK(FMIN9,INDX)
	CALL RDKA(NAM1,IDK)            !READ DK INTO COMMON KVAL
					!USES LUN=4
	CALL RHDS(NAM1,INK)            !READ HAND SCALED K INTO
					!COMMON KVAL, LUN=4
	CALL EXNAM(NAM1,NAM4,'.DIG')
	OPEN(8,FILE=NAM4,STATUS='OLD',ERR=998,IOSTAT=JER)
      N=1
    5 READ(8,4444,END=10)NYJ,(TEM1(I),SESRC(N,I),
     *NR(N,I),TEM2(I),I3R(N,I),I=1,8)
	N=N+1
      GOTO 5
   10 CLOSE(8)
C      CALL CURVK(NAM(1:2),FMIN9,INDX,K)
	OPEN (4,FILE=NAM,FORM='UNFORMATTED',ACCESS='TRANSPARENT',
     *STATUS='OLD',ERR=999)
	CALL EXNAM(NAM1,NAM2,'.CRV')
	OPEN(UNIT=2,FILE=NAM2,STATUS='OLD',
     *FORM='UNFORMATTED',ACCESS='TRANSPARENT')
	WRITE(*,1015)                   !Biginning date?
	READ(*,1006)IDATE
	IB=GYJD(IDATE)
	WRITE(*,1017)                   !Ending date?
	READ(*,1006)IDATE
	IE=GYJD(IDATE)
C      WRITE(5,1031)                   !Get data type
C      READ(5,*)IDT
	IDT=0
      JYJ=0
	WRITE(5,1020)               !Selected days?
	READ(5,1021)IANS
	ISEL=0
      IF(IANS.EQ.'Y' .OR. IANS.EQ.'y')THEN
	  CALL EXNAM(NAM1,NAM3,'.LST')
	  OPEN(UNIT=3,FILE=NAM3,STATUS='OLD',FORM='FORMATTED')
        READ(3,1016)JYJ
	  ISEL=1
	END IF
   60 WRITE(*,1035)
 1035 FORMAT('&',' Output Graphics to File? (Y/[N]) ')
	READ(*,1021)IPRN
	IF(IPRN.EQ.'y')IPRN='Y'
	IF(IPRN.EQ.'Y')THEN
	  CALL EXNAM(NAM1,NAM4,'.PLT')
	  IERR=0
	  CALL DVRINS("D:\GRAFPRINT\XPRINT.BIN",NAM4,IERR)
	  IF(IERR.NE.0)THEN
	    PRINT *,'  Driver Error=',IERR
	    STOP
	  ELSE
	    CALL PLOTS(1,0,0)
	  ENDIF
	ELSE
	  CALL PLOTS(0,1,0)
	ENDIF
	CALL NEWPEN(15)
	READ(2,ERR=69)IZ
C      OPEN(UNIT=8,FILE='TEST',STATUS='UNKNOWN',FORM='FORMATTED')
      GOTO 70
   69 PRINT *,'*******ERROR READING IZ'
      GOTO 888
   70 READ(4,END=888,ERR=71,IOSTAT=IER)IX
	IYJ=IX(5762)
      GOTO 72
   71 WRITE(5,1005)MOD(IER,256)
	IF(IER.NE.34)GOTO 888
   72 CONTINUE
      READ(2,ERR=73, END=888)IZD
      GOTO 74
   73 PRINT *,'*******ERROR READING IZD'
      GOTO 888
   74 IF(ISEL.NE.0)THEN
	  IF(IYJ.NE.JYJ)GOTO 70
      ELSE
        IF(IYJ.LT.IB)GOTO 70
      END IF
      IF(IDT.NE.0)THEN
        DO I=1,1440
          IF(W(I,2).NE.32767)THEN
            IF(IDT.EQ.1)THEN
              IF(W(I,1).NE.32767)W(I,1)=W(I,1)*SV(1)
              W(I,2)=W(I,2)*SV(2)
            ELSE
              W(I,2)=W(I,2)/XD
            END IF
          END IF
        END DO
      END IF
      IYR=IYJ/1000
      JD=IYJ-IYR*1000
      IYR=IYR+70
      MO=GETMO(IYR,JD)
      IDAY=GETDAY(IYR,JD)
      CALL CHEAD1(ID3,MO,IDAY,IYR,STDATE)
	CALL KBCLR                       !CLEAR KEYBOARD INPUT BUFFER
	DO E=1,2
	  IF(E.EQ.2)YI=YI-EO
	  CALL CTR3(E,IV,PYAM,ANUM)               !Draw traces
	  CALL KBG01(STDATE,IV,E)                 !Draw plot background
	  IF(E.EQ.2)THEN
	    X=XI+(BOXW/8.0)*0.5-5.*HSC/7.
	    B=YI+5.*HSC
	    DO J=1,8
		CALL NEWPEN(15)
		IF(DK(IDAY,J).NE.99.9.AND.NK(IDAY,J).NE.10)THEN
		  II=INT(DK(IDAY,J))-NK(IDAY,J)+4
		  IF(II.LT.1)II=1
C              IF(II.GT.7)WRITE(8,*)IDAY,J,DK(IDAY,J)
		  IF(II.GT.7)II=7
		  KK=NK(IDAY,J)+1
		  NUM(KK,J,II)=NUM(KK,J,II)+1
		  IF(II.NE.4)CALL NEWPEN(4)
		ENDIF
		Y=B
		IF(NR(IDAY,J).GE.0)Y=Y+EO
		CALL NUMBER(X,Y,HSC,SESRC(IDAY,J),0.,1)
		Y=Y-HSC-0.1*C
            V=FLOATI(I3R(IDAY,J))
            RK=RKV(V,FMIN9,INDX,II)
		CALL NUMBER(X,Y,HSC,RK,0.,1)
		Y=Y-HSC-0.1*C
		CALL NUMBER(X,Y,HSC,DK(IDAY,J),0.,1)
            IF(INK.EQ.0)THEN
		  Y=Y-HSC-0.1*C
              V=FLOAT(NK(IDAY,J))
		  CALL NUMBER(X,Y,HSC,V,0.,1)
		END IF
		X=X+(BOXW/8.0)
          END DO
        END IF
	END DO
	YI=YI+EO
	CALL WHEN(DATEST,TIMEST)
	IF(IPRN.NE.'Y')I=IXKEY()       !WAIT FOR KEYBOARD INPUT
	CALL PLOT(0.,0.,-999)
      IF(ISEL.NE.0)THEN
	  READ(3,1016)JYJ
	  IF(JYJ.EQ.999)GOTO 80
	  IF(JYJ.GT.0)GOTO 70
      END IF
	IF(IYJ.LT.IE)GOTO 70
C      CLOSE(8)
   80 CALL DIFTAB(NAM1,NUM)          !Difference dK-nK, LUN=8
  888 CLOSE(4)
	CALL PLOT(0.,0.,999)
	IF(IPRN.EQ.'Y')CALL DVRRMV(IERR)
      CLOSE(UNIT=2)
      IF(ISEL.NE.0)CLOSE(UNIT=3)
      GOTO 999
  998 WRITE(5,1055)NAM3,MOD(JER,256)
 1000 FORMAT('  Enter NGIC 1-minute value Filename> ')
 1005 FORMAT('  I/O ERROR=',I6)
 1006 FORMAT(A)
 1015 FORMAT(1H&,' Beginning Date of Input File [i.e., MM/DD/YY]> ')
 1016 FORMAT(I6)
 1017 FORMAT(1H&,' Ending Date of Input File [i.e., MM/DD/YY]> ')
 1020 FORMAT(1H&,' Plot Selected Days(Y/[N]): ')
 1021 FORMAT(A1)
 1031 FORMAT(1H&,' DATA TYPE: 0=GAMMA, 1=OMIS, 2=SYN: ')
 1055 FORMAT(2X,A31,I6)
 4444 FORMAT(I6,4(I6,F6.1,3I6),/,6X,4(I6,F6.1,3I6))
  999 STOP
      END

C-----------------------------------------------------------------------
      SUBROUTINE WHEN(DATEST,TIMEST)
      CHARACTER*8 TIMEST
      CHARACTER*9 DATEST
C
      CALL SYMBOL(1.1,-0.1,.07,DATEST,0.,9)
      CALL SYMBOL(3.5,-0.1,.07,TIMEST,0.,8)
      RETURN
      END

